@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen::AccessTable::DBI;
 
-our $DATE = '2015-02-18'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2015-07-15'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,6 +65,10 @@ table_spec from table schema if table_spec is not specified.
 _
         },
     },
+    modify_meta => sub {
+        my $meta = shift;
+        push @{ $meta->{'x.dynamic_generator_modules'} }, __PACKAGE__;
+    },
 );
 sub gen_read_dbi_table_func {
     my %args = @_;
@@ -105,7 +109,7 @@ sub gen_read_dbi_table_func {
         my $filtered;
         my @wheres;
         # XXX case_insensitive_search & word_search not yet observed
-        my $q = $query->{q};
+        my $q = $query->{query};
         if (defined($q) && @searchable_fields) {
             push @wheres, "(".
                 join(" OR ", map {$qi->($fspecs->{$_}{db_field}//$_)." LIKE ".
@@ -215,7 +219,7 @@ Perinci::Sub::Gen::AccessTable::DBI - Generate function (and its metadata) to re
 
 =head1 VERSION
 
-This document describes version 0.12 of Perinci::Sub::Gen::AccessTable::DBI (from Perl distribution Perinci-Sub-Gen-AccessTable-DBI), released on 2015-02-18.
+This document describes version 0.13 of Perinci::Sub::Gen::AccessTable::DBI (from Perl distribution Perinci-Sub-Gen-AccessTable-DBI), released on 2015-07-15.
 
 =head1 SYNOPSIS
 
@@ -399,6 +403,8 @@ Supply default 'with_field_names' value in generated function's metadata.
 
 Generated function's description.
 
+=item * B<detail_aliases> => I<hash>
+
 =item * B<enable_field_selection> => I<bool> (default: 1)
 
 Decide whether generated function will support field selection (the `fields` argument).
@@ -431,6 +437,8 @@ Filtering must also be enabled (C<enable_filtering>).
 
 Extra arguments for the generated function.
 
+=item * B<fields_aliases> => I<hash>
+
 =item * B<hooks> => I<hash>
 
 Supply hooks.
@@ -492,6 +500,16 @@ supply this if you set C<install> to false.
 
 If not specified, caller's package will be used by default.
 
+=item * B<query_aliases> => I<hash>
+
+=item * B<random_aliases> => I<hash>
+
+=item * B<result_limit_aliases> => I<hash>
+
+=item * B<result_start_aliases> => I<hash>
+
+=item * B<sort_aliases> => I<hash>
+
 =item * B<summary> => I<str>
 
 Generated function's summary.
@@ -509,6 +527,8 @@ specification can have a key called C<db_field> to specify the database field (i
 different). Currently this is required. Future version will be able to generate
 table_spec from table schema if table_spec is not specified.
 
+=item * B<with_field_names_aliases> => I<hash>
+
 =item * B<word_search> => I<bool> (default: 0)
 
 Decide whether generated function will perform word searching instead of string searching.
